@@ -95,9 +95,9 @@ static const char *CALL_METHYLATION_USAGE_MESSAGE =
 "  -v, --verbose                        display verbose output\n"
 "      --version                        display version\n"
 "      --help                           display this help and exit\n"
-"  -r, --reads=FILE                     the ONT reads are in fasta FILE\n"
+"  -r, --reads=FILE                     the ONT reads are in fasta/fastq FILE\n"
 "  -b, --bam=FILE                       the reads aligned to the genome assembly are in bam FILE\n"
-"  -g, --genome=FILE                    the genome we are computing a consensus for is in FILE\n"
+"  -g, --genome=FILE                    the genome we are calling methylation for is in fasta FILE\n"
 "  -q, --methylation=STRING             the type of methylation (cpg,gpc,dam,dcm)\n"
 "  -t, --threads=NUM                    use NUM threads (default: 1)\n"
 "      --progress                       print out a progress message\n"
@@ -323,6 +323,12 @@ void calculate_methylation_for_read(const OutputHandles& handles,
             double sum_ll_u = ss.ll_unmethylated[0] + ss.ll_unmethylated[1];
             double diff = sum_ll_m - sum_ll_u;
 
+            // do not output if outside the window boundaries
+            if((region_start != -1 && ss.start_position < region_start) ||
+               (region_end != -1 && ss.end_position >= region_end)) {
+                continue;
+            }
+
             fprintf(handles.site_writer, "%s\t%s\t%d\t%d\t", ss.chromosome.c_str(), read_orientation.c_str(), ss.start_position, ss.end_position);
             fprintf(handles.site_writer, "%s\t%.2lf\t", sr.read_name.c_str(), diff);
             fprintf(handles.site_writer, "%.2lf\t%.2lf\t", sum_ll_m, sum_ll_u);
@@ -415,6 +421,11 @@ int call_methylation_main(int argc, char** argv)
 
     // load reference fai file
     faidx_t *fai = fai_load(opt::genome_file.c_str());
+    if(fai == NULL) {
+        fprintf(stderr, "Error: could not open genome file: %s\n", opt::genome_file.c_str());
+        fprintf(stderr, "Please check the path is correct\n");
+        exit(1);
+    }
 
 #ifndef H5_HAVE_THREADSAFE
     if(opt::num_threads > 1) {
@@ -427,7 +438,7 @@ int call_methylation_main(int argc, char** argv)
     // Initialize writers
     OutputHandles handles;
     handles.site_writer = stdout;
-    
+
     // Write header
     fprintf(handles.site_writer, "chromosome\tstrand\tstart\tend\tread_name\t"
                                  "log_lik_ratio\tlog_lik_methylated\tlog_lik_unmethylated\t"
